@@ -1,9 +1,9 @@
 package TableData::Sample::DeNiro;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-11'; # DATE
+our $DATE = '2021-04-13'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use Role::Tiny::With;
 with 'TableDataRole::Source::CSVDATA';
@@ -21,7 +21,7 @@ TableData::Sample::DeNiro - Rotten Tomato ratings of movies with Robert De Niro
 
 =head1 VERSION
 
-This document describes version 0.007 of TableData::Sample::DeNiro (from Perl distribution TableDataRoles-Standard), released on 2021-04-11.
+This document describes version 0.008 of TableData::Sample::DeNiro (from Perl distribution TableDataRoles-Standard), released on 2021-04-13.
 
 =head1 HOMEPAGE
 
@@ -29,11 +29,11 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDataR
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TablesRoles-Standard>.
+Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-TableDataRoles-Standard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -45,7 +45,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
